.. currentmodule:: gwpy.timeseries

#####################
`TimeSeries` examples
#####################

.. toctree::
   :maxdepth: 1
   :numbered:

   public
   filter
   whiten
   correlate
   blrms
   statevector
   qscan
   pycbc-snr
   inject
